==> anywhereSSL_0.4.0.tar.gz: anywhereSSL/include/buffering.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslDefaultBuf') ) {

	/**
	 * awsslDefaultBuf
	 * 
	 * @param $buf
	 * @return void
	 */
	function awsslDefaultBuf( $buf ) {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );

		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( ! empty($awssl_config) ) {

			//*************************************************************************/
			// $Anywheressl饹Υ󥹥
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );

			//*************************************************************************/
			// ߤΥץȥ˹碌ơXOOPS_URL񤭴
			//*************************************************************************/
			if ( $Anywheressl->isSSL() ) {
				$buf = str_replace( $Anywheressl->non_ssl_url, $Anywheressl->ssl_url, $buf );
			} else {
				$buf = str_replace( $Anywheressl->ssl_url, $Anywheressl->non_ssl_url, $buf );
			}

			//*************************************************************************/
			// ֥åν񤭴
			//*************************************************************************/
			// ΰŹ沽ͭʤ顢user.phpΥURL񤭴
			if ( $awssl_config['login_on_ssl']['conf_value'] === 'yes' && ! $Anywheressl->isSSL() ) {
				// system_userform.htmlν񤭴
				$pattern = '<form action="user.php" method="post">';
				$replacement = '<form action="' .urldecode( $awssl_config['ssl_url']['conf_value'] ) .'/user.php" method="post">';
				$buf = str_replace( $pattern, $replacement, $buf );

				// system_block_login.htmlν񤭴
				$pattern = '<form style="margin-top: 0px;" action="' .XOOPS_URL .'/user.php" method="post">';
				$replacement = '<form style="margin-top: 0px;" action="' .urldecode( $awssl_config['ssl_url']['conf_value'] ) .'/user.php" method="post">';
				$buf = str_replace( $pattern, $replacement, $buf );

				// login.phpURL񤭴
				$pattern = $Anywheressl->non_ssl_url .'/login.php';
				$replacement = $Anywheressl->ssl_url .'/login.php';
				$buf = str_replace( $pattern, $replacement, $buf );

				$xoops_redirect = $Anywheressl->getXoopsRedirect( true );
			} else {
				// xoops_redirect񤭴(xreaʤɤΥСץĶб)
				$xoops_redirect = $Anywheressl->getXoopsRedirect( false );
			}
			$pattern = '/(<input type=[\'\"]hidden[\'\"][\d\D]*?)(name=[\'\"]xoops_redirect[\'\"][\d\D]*?)(value=[\'\"])([\d\D]*?)([\'\"][\d\D]*?>)/i';
			$replacement = "\${1}\${2}\${3}" .$xoops_redirect ."\${5}";
			$buf = preg_replace( $pattern, $replacement, $buf );

		}
		return $buf;
	}

}

if ( ! function_exists('awsslLoginPhpBuf') ) {

	/**
	 * awsslLoginPhpBuf
	 * 
	 * @param $buf
	 * @return void
	 */
	function awsslLoginPhpBuf( $buf ) {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );

		//*****************************************************************************/
		// ƥɥν񤭴
		//*****************************************************************************/
		$buf = str_replace( 
			'onclick="javascript:window.close();"', 
			'onclick="window.close();window.opener.location.href=&quot;' .XOOPS_URL .'/&quot;;"', 
			$buf 
		);
		return $buf;
	}

}

?>

==> anywhereSSL_0.4.1.tar.gz: anywhereSSL/include/buffering.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/ 
// ľܸƤӽФ줿exit
//*****************************************************************************/ 
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslDefaultBuf') ) {

	/**
	 * awsslDefaultBuf
	 * 
	 * @param $buf
	 * @return void
	 */
	function awsslDefaultBuf( $buf ) {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );

		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( ! empty($awssl_config) ) {

			//*************************************************************************/
			// $Anywheressl饹Υ󥹥
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );

			//*************************************************************************/
			// ߤΥץȥ˹碌ơXOOPS_URL񤭴
			//*************************************************************************/
			$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
			$current_path = strtr( $_SERVER['SCRIPT_FILENAME'], $replace_array );
			if ( $current_path !== strtr(dirname(dirname(__FILE__)), $replace_array) .'/admin/config.php' ) {
				if ( $Anywheressl->isSSL() ) {
					$buf = str_replace( $Anywheressl->non_ssl_url, $Anywheressl->ssl_url, $buf );
				} else {
					$buf = str_replace( $Anywheressl->ssl_url, $Anywheressl->non_ssl_url, $buf );
				}
			}

			//*************************************************************************/
			// ֥åν񤭴
			//*************************************************************************/
			// ΰŹ沽ͭʤ顢user.phpΥURL񤭴
			if ( $awssl_config['login_on_ssl']['conf_value'] === 'yes' && ! $Anywheressl->isSSL() ) {
				// system_userform.htmlν񤭴
				$pattern = '<form action="user.php" method="post">';
				$replacement = '<form action="' .urldecode( $awssl_config['ssl_url']['conf_value'] ) .'/user.php" method="post">';
				$buf = str_replace( $pattern, $replacement, $buf );

				// system_block_login.htmlν񤭴
				$pattern = '<form style="margin-top: 0px;" action="' .XOOPS_URL .'/user.php" method="post">';
				$replacement = '<form style="margin-top: 0px;" action="' .urldecode( $awssl_config['ssl_url']['conf_value'] ) .'/user.php" method="post">';
				$buf = str_replace( $pattern, $replacement, $buf );

				// login.phpURL񤭴
				$pattern = $Anywheressl->non_ssl_url .'/login.php';
				$replacement = $Anywheressl->ssl_url .'/login.php';
				$buf = str_replace( $pattern, $replacement, $buf );

				$xoops_redirect = $Anywheressl->getXoopsRedirect( true );
			} else {
				// xoops_redirect񤭴(xreaʤɤΥСץĶб)
				$xoops_redirect = $Anywheressl->getXoopsRedirect( false );
			}
			$pattern = '/(<input type=[\'\"]hidden[\'\"][\d\D]*?)(name=[\'\"]xoops_redirect[\'\"][\d\D]*?)(value=[\'\"])([\d\D]*?)([\'\"][\d\D]*?>)/i';
			$replacement = "\${1}\${2}\${3}" .$xoops_redirect ."\${5}";
			$buf = preg_replace( $pattern, $replacement, $buf );

		}
		return $buf;
	}

}

if ( ! function_exists('awsslLoginPhpBuf') ) {

	/**
	 * awsslLoginPhpBuf
	 * 
	 * @param $buf
	 * @return void
	 */
	function awsslLoginPhpBuf( $buf ) {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );

		//*****************************************************************************/
		// ƥɥν񤭴
		//*****************************************************************************/
		$buf = str_replace( 
			'onclick="javascript:window.close();"', 
			'onclick="window.close();window.opener.location.href=&quot;' .XOOPS_URL .'/&quot;;"', 
			$buf 
		);
		return $buf;
	}

}

?>
